@@ -560,7 +560,7 @@ go back to ((<Index>))
     # 欠損値に 0 を入れて普通に sum する
     ary0 = @array.dup
     ary0[@mask.not] = 0
-    NArrayMiss.reduction(@mask, min_count, dims, false, typecode) do
+    NArrayMiss.reduction(@mask, rank, min_count, dims, false, typecode) do
       ary0.sum(*dims)
     end
   end
@@ -570,7 +570,7 @@ go back to ((<Index>))
     # byte,sint,int,sfloat,float の MAX の値を入れるように変更すべき
     ary0 = @array.dup
     ary0[@mask.not] = @array.max
-    NArrayMiss.reduction(@mask, min_count, dims, false, typecode) do
+    NArrayMiss.reduction(@mask, rank, min_count, dims, false, typecode) do
       ary0.min(*dims)
     end
   end
@@ -580,7 +580,7 @@ go back to ((<Index>))
     # byte,sint,int,sfloat,float の MIN の値を入れるように変更すべき
     ary0 = @array.dup
     ary0[@mask.not] = @array.min
-    NArrayMiss.reduction(@mask, min_count, dims, false, typecode) do
+    NArrayMiss.reduction(@mask, rank, min_count, dims, false, typecode) do
       ary0.max(*dims)
     end
   end
@@ -589,7 +589,7 @@ go back to ((<Index>))
     min_count = NArrayMiss.check_options(dims, 1)
     # 整数型の場合は浮動小数型へ変換
     ary0 = self.integer? ? self.to_type(NArray::DFLOAT) : self
-    NArrayMiss.reduction(@mask, min_count, dims, true, typecode) do |count_sum, count_accum|
+    NArrayMiss.reduction(@mask, rank, min_count, dims, true, typecode) do |count_sum, count_accum|
       ary0.sum(*dims)/count_sum
     end
   end
@@ -597,7 +597,7 @@ go back to ((<Index>))
     min_count = NArrayMiss.check_options(dims, 2)
     # 整数型の場合は浮動小数型へ変換
     ary0 = self.integer? ? self.to_type(NArray::DFLOAT) : self
-    NArrayMiss.reduction(@mask, min_count, dims, true, typecode) do |count_sum, count_accum|
+    NArrayMiss.reduction(@mask, rank, min_count, dims, true, typecode) do |count_sum, count_accum|
       ary0 = ary0 - ary0.accum(*dims)/count_accum
       ary0 = ary0.abs if ary0.complex?
       ary0 = (ary0**2).sum(*dims) / (count_sum-1)
@@ -608,7 +608,7 @@ go back to ((<Index>))
     min_count = NArrayMiss.check_options(dims, 1)
     # 整数型の場合は浮動小数型へ変換
     ary0 = self.integer? ? self.to_type(NArray::DFLOAT) : self
-    NArrayMiss.reduction(@mask, min_count, dims, true, typecode) do |count_sum, count_accum|
+    NArrayMiss.reduction(@mask, rank, min_count, dims, true, typecode) do |count_sum, count_accum|
       ary0 = ary0.abs if ary0.complex?
       ary0 = (ary0**2).sum(*dims) / count_sum
       NMMath.sqrt(ary0)
@@ -618,7 +618,7 @@ go back to ((<Index>))
     min_count = NArrayMiss.check_options(dims, 1)
     # 整数型の場合は浮動小数型へ変換
     ary0 = self.integer? ? self.to_type(NArray::DFLOAT) : self
-    NArrayMiss.reduction(@mask, min_count, dims, true, typecode) do |count_sum, count_accum|
+    NArrayMiss.reduction(@mask, rank, min_count, dims, true, typecode) do |count_sum, count_accum|
       ary0 = ary0 - ary0.accum(*dims)/count_accum
       ary0 = ary0.abs if ary0.complex?
       ary0 = (ary0**2).sum(*dims) / count_sum
@@ -1305,7 +1305,7 @@ go back to ((<Index>))
   end
 
 
-  def self.reduction(mask, min_count, dims, flag, typecode)
+  def self.reduction(mask, rank, min_count, dims, flag, typecode)
     # flag: リダクションを行う次元方向の有効な値の個数で、割り算を行うかどうかのフラグ
     count_sum = mask.to_type(NArray::LINT).sum(*dims)
     # 返り値が配列か、スカラーかによって分岐
@@ -1314,7 +1314,7 @@ go back to ((<Index>))
       # すべての要素が欠損値にならないかチェック
       if mask.any?
         count_accum = NArray.ref(count_sum)
-        dims.collect{|d|d<0 ? d+mask.rank : d}.sort.each do |d|
+        dims.collect{|d|d<0 ? d+rank : d}.sort.each do |d|
           count_accum.newdim!(d)
         end
         # 割り算を行う場合は、先に count_sum を NArrayMiss 化
@@ -1494,7 +1494,7 @@ module NMMath
         mask = mask0.nil? ? mask1 : mask1.nil? ? mask0 : mask0&mask1
         ary0.set_mask(mask)
         ary1.set_mask(mask)
-        NArrayMiss.reduction(mask, min_count, dims, true, NArray::DFLOAT) do |count_sum, count_accum|
+        NArrayMiss.reduction(mask, ary0.rank, min_count, dims, true, NArray::DFLOAT) do |count_sum, count_accum|
           #{hash[:post]}
         end
       end
